# Generated by Django 5.0.9 on 2024-10-21 14:53

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('ptuevents', '0003_alter_ptappsystem_custom_field_data_and_more'),
    ]

    operations = [
        migrations.RenameField(
            model_name='ptappsystemassignment',
            old_name='content_type',
            new_name='object_type',
        ),
        migrations.RenameField(
            model_name='ptueventassignment',
            old_name='content_type',
            new_name='object_type',
        ),
        migrations.RenameField(
            model_name='ptworkstationsassignment',
            old_name='content_type',
            new_name='object_type',
        ),
        migrations.AlterUniqueTogether(
            name='ptappsystemassignment',
            unique_together={('object_type', 'object_id', 'app_system')},
        ),
        migrations.AlterUniqueTogether(
            name='ptueventassignment',
            unique_together={('object_type', 'object_id', 'ptuevent', 'relation')},
        ),
        migrations.AlterUniqueTogether(
            name='ptworkstationsassignment',
            unique_together={('object_type', 'object_id', 'pt_workstations')},
        ),
    ]
