# Generated by Django 4.2.7 on 2024-10-17 10:48

from django.db import migrations, models
import utilities.json


class Migration(migrations.Migration):

    dependencies = [
        ('ptuevents', '0002_add_sid_location'),
    ]

    operations = [
        migrations.AlterField(
            model_name='ptappsystem',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptuevent',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptueventrelation',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptusers',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptusers',
            name='status',
            field=models.CharField(default='enabled', max_length=250),
        ),
        migrations.AlterField(
            model_name='ptworkstations',
            name='ad_description',
            field=models.CharField(blank=True, max_length=500),
        ),
        migrations.AlterField(
            model_name='ptworkstations',
            name='custom_field_data',
            field=models.JSONField(blank=True, default=dict, encoder=utilities.json.CustomFieldJSONEncoder),
        ),
        migrations.AlterField(
            model_name='ptworkstations',
            name='description',
            field=models.CharField(blank=True, max_length=500),
        ),
    ]
