{% extends 'generic/object.html' %}
{% load helpers %} {% load plugins %}
{%load render_table from django_tables2 %}
{% block content %}
  <div class="row mb-3">
    <div class="col col-md-6">
      <div class="card">
        <h5 class="card-header">Workstation</h5>
        <table class="table table-hover attr-table">
          <tr>
            <th scope="row">Name</th>
            <td>{{ object.name }}</td>
          </tr>

          <tr>
            <th scope="row">CN</th>
            <td>{{ object.CN }}</td>
          </tr>
          <tr>
            <th scope="row">DistinguishedName</th>
            <td>{{ object.DistinguishedName }}</td>
          </tr>

          <tr>
            <th scope="row">Location</th>
            <td>{{ object.location }}</td>
          </tr>

          <tr>
            <th scope="row">ad_sid</th>
            <td>{{ object.ad_sid }}</td>
          </tr>
          <tr>
            <th scope="row">ad_description</th>
            <td>{{ object.ad_description }}</td>
          </tr>

          <tr>
            <th scope="row">Description</th>
            <td>{{ object.description }}</td>
          </tr>
        </table>
      </div>
      {% include 'inc/panels/custom_fields.html' %}
    </div>
    <div class="col col-md-6">
      {% include 'inc/panels/tags.html' %}
      {% include 'inc/panels/comments.html' %}
      {% include 'ptuevents/ptuevent_panel.html' %}
    </div>
  </div>
<div class="row mb-3">
  <div class="col col-md-12">
    <div class="card">
      <h5 class="card-header">Assignments</h5>
      <div class="card-body table-responsive">
        {% render_table assignments_table 'inc/table.html' %}
      </div>
    </div>
    {% plugin_full_width_page object %}
  </div>
</div>
{% endblock content %}